@@ -7,7 +7,7 @@ use Mouse;
 extends 'MouseX::Types::Enum';
 
 has name => (is => 'ro', isa => 'Str');
-has color => (is => 'ro', isa => 'Str');
+has color => (is => 'ro', isa => 'Str', required => 1);
 has price => (is => 'ro', isa => 'Num');
 has has_seed => (is => 'ro', isa => 'Int', default => 1);
 
@@ -36,4 +36,4 @@ sub BANANA {3 => (
 
 __PACKAGE__->_build_enum;
 
-1;
\ No newline at end of file
+1;
